pub struct DeviceGeolocation {
pub point: Option<Geolocation>,
}Expand description
Device geolocation JSON schema.
This JSON schema corresponds to GET and PUT requests on
/api/geolocation. The GET request contains the current device geolocation,
or None if it has never been set or if it has been cleared. The PUT
request sets the current device geolocation, or clears it the request
contains None.
Fields
point: Option<Geolocation>Current device geolocation.