pub struct PatchSpectrometer {
    pub output_sampling_frequency: Option<f64>,
    pub number_integrations: Option<u32>,
    pub mode: Option<SpectrometerMode>,
}
Spectrometer PATCH JSON schema.

This JSON schema corresponds to PATCH requests on /api/spectrometer. It is used to change the spectrometer rate, by specifying the target output sampling frequency, or the number of integrations. Since each parameter can be computed in terms of the other, only one of them should be used in the PATCH request.

Fields

output_sampling_frequency: Option<f64>

Output sampling frequency in samples per second.

number_integrations: Option<u32>

Number of non-coherent integrations.

mode: Option<SpectrometerMode>

Spectrometer mode.